@@ -11,5 +11,5 @@ config() {
 }
 
 config etc/mutt/Muttrc.new
-( cd usr/doc ; rm -rf mutt-1.4.1i )
-( cd usr/doc ; ln -sf mutt mutt-1.4.1i )
+( cd usr/doc ; rm -rf mutt-1.4.2.1i )
+( cd usr/doc ; ln -sf mutt mutt-1.4.2.1i )
